# pyw-vision
[![PyPI](https://img.shields.io/pypi/v/pyw-vision.svg)](https://pypi.org/project/pyw-vision/)
[![CI](https://github.com/pythonWoods/pyw-vision/actions/workflows/ci.yml/badge.svg)](https://github.com/pythonWoods/pyw-vision/actions/workflows/ci.yml)
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](LICENSE)

Reserved placeholder for pyw-vision (vision utilities).


## Links utili
Documentazione dev (work-in-progress) → https://pythonwoods.dev/docs/pyw-vision/latest/

Issue tracker → https://github.com/pythonWoods/pyw-vision/issues

Changelog → https://github.com/pythonWoods/pyw-vision/releases

© pythonWoods — MIT License